﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Data.Entity;
using System.Linq.Expressions;
using System.Data;

namespace FoxCommerce.MVC.Data.Infrastructure
{
    public class EntityRepository<TEntityType> : RepositoryBase where TEntityType : class
    {
        //$--Privates
        private readonly IDbSet<TEntityType> dbset;
        //$--Properties

        public IEnumerable<TEntityType> All
        {
            get { return dbset.ToList(); }
        }
        //$-- Ctor
        public EntityRepository(IDatabaseFactory databaseFactory)
            : base(databaseFactory)
        {
            dbset = DataContext.Set<TEntityType>();
        }
        //$-- Public Methods
        public virtual void Insert(TEntityType entity)
        {
            dbset.Add(entity);
        }

        public virtual void Delete(TEntityType entity)
        {
            dbset.Remove(entity);
        }



        public virtual IEnumerable<TEntityType> GetMany(Func<TEntityType, bool> where)
        {
            return dbset.Where(where).ToList();
        }
        public TEntityType Get(Func<TEntityType, Boolean> where)
        {
            return dbset.Where(where).FirstOrDefault<TEntityType>();
        }


        public IQueryable<TEntityType> AllIncluding(params Expression<Func<TEntityType, object>>[] includeProperties)
        {
            IQueryable<TEntityType> query = dbset;
            foreach (var includeProperty in includeProperties)
            {
                query = query.Include(includeProperty);
            }
            return query;
        }

        public TEntityType Find(int id)
        {
            return dbset.Find(id);
        }

        public void Update(TEntityType entity)
        {
            // Existing entity
            DataContext.Entry(entity).State = EntityState.Modified;
        }

        public void Delete(int id)
        {
            var entity = dbset.Find(id);
            dbset.Remove(entity);
        }
    }
}