﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using FoxCommerce.MVC.Domain.Entities;
using FoxCommerce.MVC.Data.Repositories;
using FoxCommerce.MVC.Data.Infrastructure;


namespace FoxCommerce.MVC.Service
{
    public interface ISecurityService
    {
        IEnumerable<User> GetUsers();
        User GetUser(string userName);
        void CreateUser(User user);
        void DeleteUser(string userName);

        IEnumerable<Role> Roles();
        Role GetRole(string roleName);
        void CreateRole(Role role);
        void DeleteRole(string roleName);
        void Save();

        void AssignRole(string userName, List<string> roleNames);


    }
    public class SecurityService : ISecurityService
    {
        private readonly IUserRepository userRepository;
        private readonly IRoleRepository roleRepository;
        private readonly IUnitOfWork unitOfWork;
        public SecurityService(IUserRepository userRepository, IRoleRepository roleRepository, IUnitOfWork unitOfWork)
        {
            this.userRepository = userRepository;
            this.roleRepository = roleRepository;
            this.unitOfWork = unitOfWork;
        }
        public IEnumerable<User> GetUsers()
        {
            var users = userRepository.All;
            return users;
        }

        public User GetUser(string userName)
        {
            var user = userRepository.FindUser(userName);
            return user;
        }

        public void CreateUser(User user)
        {
            userRepository.Insert(user);
            Save();
        }

        public void DeleteUser(string userName)
        {
            var user = GetUser(userName);
            userRepository.Delete(user);
            Save();
        }

        public IEnumerable<Role> Roles()
        {
            var roles = roleRepository.All;
            return roles;
        }

        public Role GetRole(string roleName)
        {
            var role = roleRepository.FindRole(roleName);
            return role;
        }

        public void CreateRole(Role role)
        {
            roleRepository.Insert(role);
            Save();
        }

        public void DeleteRole(string roleName)
        {
            var role = GetRole(roleName);
            roleRepository.Delete(role);
            Save();
        }
        public void AssignRole(string userName, List<string> roleNames)
        {
            userRepository.AssignRole(userName, roleNames);
            Save();
        }

        public void Save()
        {
            unitOfWork.Commit();
        }

    }
}
