﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using System.Web.Routing;
using FoxCommerce.MVC.Data;
using Microsoft.Practices.Unity;
using FoxCommerce.MVC.Web.IoC;
using FoxCommerce.MVC.Data.Infrastructure;
using FoxCommerce.MVC.Data.IRepositories;
using FoxCommerce.MVC.Data.Repositories;
using FoxCommerce.MVC.Service.IServices;
using FoxCommerce.MVC.Service;
using System.Web.Security;
using FoxCommerce.MVC.Web.Models;
using FoxCommerce.MVC.Web.Helpers;

namespace FoxCommerce.MVC.Web
{
    // Note: For instructions on enabling IIS6 or IIS7 classic mode, 
    // visit http://go.microsoft.com/?LinkId=9394801

    public class MvcApplication : System.Web.HttpApplication
    {
        public static void RegisterGlobalFilters(GlobalFilterCollection filters)
        {
            filters.Add(new HandleErrorAttribute());
        }

        public static void RegisterRoutes(RouteCollection routes)
        {
            routes.IgnoreRoute("{resource}.axd/{*pathInfo}");

            routes.MapRoute(
                "Default", // Route name
                "{controller}/{action}/{id}", // URL with parameters
                new { controller = "Pictures", action = "Index", id = UrlParameter.Optional }, // Parameter defaults
                new[] { "FoxCommerce.MVC.Web.Controllers" }
            );

        }

        protected void Application_Start()
        {
            AreaRegistration.RegisterAllAreas();
            GlobalFilters.Filters.Add(new RedirectMobileDevicesToMobileAreaAttribute(), 1);
            RegisterGlobalFilters(GlobalFilters.Filters);

            RegisterRoutes(RouteTable.Routes);

            System.Data.Entity.Database.SetInitializer(new System.Data.Entity.DropCreateDatabaseIfModelChanges<FoxCommerceMVCWebContext>());

            IUnityContainer container = GetUnityContainer();
            DependencyResolver.SetResolver(new UnityDependencyResolver(container));
        }
        private IUnityContainer GetUnityContainer()
        {
            //Create UnityContainer          
            IUnityContainer container = new UnityContainer()
                //.RegisterType<IControllerActivator, CustomControllerActivator>() // No need to a controller activator
            .RegisterType<IFormsAuthenticationService, FormsAuthenticationService>()
            .RegisterType<IMembershipService, AccountMembershipService>()
            .RegisterInstance<MembershipProvider>(Membership.Provider)
            .RegisterType<IDatabaseFactory, DatabaseFactory>(new HttpContextLifetimeManager<IDatabaseFactory>())
            .RegisterType<IUnitOfWork, UnitOfWork>(new HttpContextLifetimeManager<IUnitOfWork>())
            .RegisterType<IPictureRepository, PictureRepository>(new HttpContextLifetimeManager<IPictureRepository>())
            .RegisterType<IPictureService, PictureService>(new HttpContextLifetimeManager<IPictureService>());
            return container;
        }
    }
}